<?php
/**
 * PHP Demo page for Card Gate Gateway using class
 * (C)2014 Card Gate B.V.
 *
 * V1.0 (LH) - 2014-06-27
 */

require 'CardGate.class.php';

# Enter the correct Site info from https://merchants.cardgateplus.com/
$oCG = new CardGate( 1001, 'DEMO', TRUE );

# If you leave these out, the system will use the defaults entered in the backoffice
$sReturnURL = 'http://' . $_SERVER[ 'HTTP_HOST' ] . dirname( $_SERVER[ 'PHP_SELF' ] ) . '/voltooid.php';
$sReturnURL_Failed = 'http://' . $_SERVER[ 'HTTP_HOST' ] . dirname( $_SERVER[ 'PHP_SELF' ] ) . '/fout.php';

# Ajax request handler
######################
if ( !empty( $_REQUEST['jxupdate'] ) ) {
	# Convert amount to cents
	$iAmount = intval( str_replace( ',', '.', $_REQUEST['amount'] ) * 100 );

	# Would be better with JSON, but this works on ancient browsers too ;-)
	die( $oCG->calculateHash( $iAmount,  $_REQUEST['ref'] ) . '|' . $iAmount );
}

# Check passed arguments
########################
$aOptionalVars = array( 'amount', 'description', 'ref', 'option', 'suboption', 'first_name', 'last_name', 'address', 'postal_code', 'city', 'country', 'email', 'phone_number' );

# Form action and optional target
$_FormAction = $oCG->getGatewayURL();
$_FormTarget = '';

# Prevent PHP notices when we display the form
foreach ( $aOptionalVars as $v ) {
	if ( !isset( $_REQUEST[ $v ] ) ) {
		if ( !empty( $_FormData ) ) {
			$_REQUEST[$v] = $_FormData[ $v ];
		} else {
			$_REQUEST[$v] = '';
		}
	} else {
		# Strip any tags to prevent XSS hacks
		$_REQUEST[$v] = strip_tags( $_REQUEST[$v] );
	}
}

if ( empty( $_REQUEST['ref'] ) ) {
	# *** NB ** REFERENCE _MUST_ BE UNIQUE FOR EACH TRANSACTION!!!
	$_REQUEST['ref'] = 'DEMO' . date( 'YmdHis' );
}

?>
<!DOCTYPE html>
<html>
	<head>
		<title>Cardgate Payment Demo</title>

		<meta charset="utf-8">
		<meta http-equiv="content-type"	content="text/html; charset=utf-8"/>
		<meta name="author"				content="Card Gate B.V." />
		<meta name="description"		content=""  />
		<meta name="keywords"			content="" />

		<script type="text/javascript">

			function selectors() {
				var pay_method;
				if ("<?php echo $_REQUEST[ 'option' ] ?>" != "") {
					var cgp_option = document.getElementById('cgp_option');
					cgp_option.options["<?php echo $_REQUEST[ 'option' ] ?>"].selected = "selected";
					document.getElementById('cgp_suboption').options["<?php echo $_REQUEST[ 'suboption' ] ?>"].selected = "selected";
					document.getElementById('country').options["<?php echo $_REQUEST[ 'country' ] ?>"].selected = "selected";
					pay_method = cgp_option.options[cgp_option.selectedIndex].value;
					show_bank(pay_method);
				}
				document.getElementById("input_amount").focus();
			}

			function show_bank(pay_method) {
				var o = document.getElementById("cgp_option");
				var oSub = document.getElementById("cgp_suboption");
				if (pay_method == 'ideal') {
					oSub.style.visibility = 'visible';
					oSub.focus();
					o.style.width = '97px';
				} else {
					if (pay_method == '' || pay_method == 'onbekend') {
						o.style.width = '180px';
					} else {
						o.style.width = '97px';
					}
					oSub.style.visibility = 'hidden';
				}
			}

			// Lightweight Ajax
			function GetXmlHttpObject() {
				var xmlHttp = null;
				try {
					// Firefox, Opera 8.0+, Safari
					xmlHttp = new XMLHttpRequest();
				} catch (e) {
					// Internet Explorer
					try {
						xmlHttp = new ActiveXObject("Msxml2.XMLHTTP");
					} catch (e) {
						xmlHttp = new ActiveXObject("Microsoft.XMLHTTP");
					}
				}
				if (xmlHttp == null) {
					alert('Your browser does not support Ajax!\nPlease use another browser.');
				}
				return xmlHttp;
			}
			var xreq = null;
			function AjaxRequest(url, handlers) {
				xreq = GetXmlHttpObject();
				if (xreq != null) {
					xreq.handlers = handlers;
					xreq.onreadystatechange = AjaxOnReadyStateChange;
					xreq.open("GET", url, true);
					xreq.send(null);
				}
			}
			function AjaxOnReadyStateChange() {
				if (xreq.readyState == 4) {
					if (xreq.status == 200) {
						if (xreq.handlers.onSuccess)
							xreq.handlers.onSuccess(xreq);
					} else if (xreq.handlers.onFailure)
						xreq.handlers.onFailure(xreq);
				}
			}
			function cgpCalcHash(oForm) {
				if (oForm.input_amount.value == '' || Math.valueOf(oForm.input_amount.value) <= 0) {
					alert('Ongeldig bedrag!');
				}
				else if (oForm.cgp_option.selectedIndex == 0) {
					alert('Kies een betaaloptie!');
				}
				else if (oForm.cgp_option.selectedIndex == 1 && oForm.cgp_suboption.selectedIndex == -1) {
					alert('Kies eerst een bank!');
				} else {
					AjaxRequest('?jxupdate=1&amount=' + oForm.input_amount.value + '&ref=' + oForm.ref.value, {
						onSuccess: function(xreq) {
							console.log( 'Ajax result=' + xreq.responseText );
							var v = xreq.responseText.split('|');
							if ('ERROR' != v[0]) {
								oForm.hash.value = v[0];
								oForm.amount.value = v[1];
								oForm.submit(); // Post everything to payment gateway
							}
						}});
					if (xreq) {
						return true;
					} else {
						alert('Fout bij verwerken van de gegevens!');
						return false;
					}
				}
			}
		</script>
		<style type="text/css">
			<!--
			.field {width:250px;}
			#input_amount {width:80px;}
			#cgp_suboption {width:149px;}
			.tr {height:30px;}
			-->
		</style>
	</head>
	<body onload="selectors()">
		<form name="cgp_payment" method="post" action="<?php echo $_FormAction ?>" target="<?php echo $_FormTarget ?>" onsubmit="cgpCalcHash(this);
				return false">
			<input type="hidden" name="siteid" value="<?php echo $oCG->getSiteID() ?>">
			<input type="hidden" name="hash" value="<?php echo $sHash ?>">
			<input type="hidden" name="test" value="<?php echo $oCG->getTestMode() ? 1 : 0 ?>">
			<input type="hidden" name="language" value="nl">
			<input type="hidden" name="return_url" value="<?php echo $sReturnURL ?>">
			<input type="hidden" name="return_url_failed" value="<?php echo $sReturnURL_Failed ?>">
			<table>
				<tr class="tr">
					<td colspan="2"><b>Betaalgegevens:</b></td>
				</tr>
				<tr>
					<td>Uw referentie</td>
					<td><input type="text" class="field" name="ref" value="<?php echo $_REQUEST[ 'ref' ] ?>" readonly></td>
				</tr>
				<tr>
					<td>Bedrag</td>
					<td><input type="hidden" id="amount" name="amount" value="<?php echo $sAmount ?>">
						&euro; <input type="text" id="input_amount" name="input_amount" value="<?php echo $_REQUEST['amount'] ?>">
					</td>
				</tr>
				<tr>
					<td>Omschrijving</td>
					<td><input type="text" class="field" name="description" value="<?php echo $_REQUEST[ 'description' ] ?>"></td>
				</tr>
				<tr>
					<td>Betaalmethode</td>
					<td>
						<select id="cgp_option" name="option" onchange="show_bank(this.options[this.selectedIndex].value)">
							<option name="onbekend" value="">Kies uw betaalmethode</option>
							<option name="ideal" value="ideal">iDEAL</option>
							<option name="mistercash" value="mistercash">Mister Cash</option>
							<option name="creditcard" value="creditcard">Creditcard</option>
						</select>
						<select id="cgp_suboption" name="suboption" style="visibility:hidden">
							<?php echo $oCG->getiDEALBanksSelect() ?>
						</select>
					</td>
				</tr>
				<tr class="tr">
					<td colspan="2"><b>Klantgegevens:</b></td>
				</tr>
				<tr>
					<td>Voornaam</td>
					<td><input type="text" class="field" name="first_name" value="<?php echo $_REQUEST[ 'first_name' ] ?>"></td>
				</tr>
				<tr>
					<td>Achternaam</td>
					<td><input type="text" class="field" name="last_name" value=" <?php echo $_REQUEST[ 'last_name' ] ?>"></td>
				</tr>
				<tr>
					<td>Adres</td>
					<td><input type="text" class="field" name="address" value="<?php echo $_REQUEST[ 'address' ] ?>"></td>
				</tr>
				<tr>
					<td>Postcode</td>
					<td><input type="text" class="field" name="postal_code" value="<?php echo $_REQUEST[ 'postal_code' ] ?>"></td>
				</tr>
				<tr>
					<td>Plaats</td>
					<td><input type="text" class="field" name="city" value="<?php echo $_REQUEST[ 'city' ] ?>"></td>
				</tr>
				<tr>
					<td>Land</td>
					<td>
						<select size="1" id="country" name="country">
							<option name="" value="">Select One</option>
							<option name="NL" value="NL" selected="selected">Netherlands</option>
							<option name="BE" value="BE">Belgi&euml;</option>
						</select>
					</td>
				</tr>
				<tr>
					<td>E-mail</td>
					<td><input type="text" class="field" name="email" value="<?php echo $_REQUEST[ 'email' ] ?>"></td>
				</tr>
				<tr>
					<td>Tel.</td>
					<td><input type="text" class="field" name="phone_number" value="<?php echo $_REQUEST[ 'phone_number' ] ?>"></td>
				</tr>
			</table>
			<input type="submit" name="send" value="Betalen">
		</form>
	</body>
</html>